# Specification Static Assets

**IMPORTANT: The canonical specs are in the repo root.**

* `*.d.ts` - copied from canonical spec at repo.
* `*.slim.d.ts` - No comments, less context.
* `*.schema.json` - Automated json conversion.

These assets are included here for easy availability for machines or to copy to SDKs.

It is recommended to directly regenerate these assets in your sdk release with `/scripts/generate-spec-assets.sh`
